* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [SAP LeanIX for Enterprise Architects](https://help.sap.com/docs/leanix/ea/for-enterprise-architects)
  * Set Up User Access
